Title: List Functions in Documentation
Version: 0.1.0
Description: Generate 'Rd' markup to list methods for a generic function. Makes it easier to document S3, S4, and S7 generics by automatically finding and linking to method documentation.
License: MIT + file LICENSE
URL: https://github.com/r-lib/doclisting, https://doclisting.r-lib.org
BugReports: https://github.com/r-lib/doclisting/issues
Depends: R (≥ 4.1)
Imports: methods
Suggests: pkgload, S7, testthat (≥ 3.0.0)
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3.9000
NeedsCompilation: no
Packaged: 2026-04-08 21:51:05 UTC; hadleywickham
Author: Hadley Wickham ORCID iD [aut, cre], Posit Software, PBC ROR ID [cph, fnd]
Maintainer: Hadley Wickham <hadley@posit.co>
Repository: CRAN
Date/Publication: 2026-04-15 13:00:35 UTC

List methods for a generic

Description

Generate Rd markup to list methods for a generic function. methods_list() generates a bulleted list and methods_inline() produces a comma-separated list, suitable for inline use.

You can use them in roxygen2 documentation in two ways:

Methods from the same package as the generic are linked without a package qualifier; methods from other packages include the package name.

Usage

methods_list(x, package = NULL)

methods_inline(x, package = NULL)

Arguments

x

Name of the generic function (a string).

package

Package that defines the generic. Should only be needed in unusual cases as the default will attempt to determine it automatically.

Value

A string containing Rd markup, or "" if no methods are found.

Examples

cat(methods_list("mean"))
cat(methods_inline("mean"))